@@ -1,4 +1,4 @@
-package VWF::Display;
+package Geo::Coder::Free::Display;
 
 # Display a page. Certain variables are available to all templates, such as
 # the stuff in the configuration file
@@ -11,7 +11,7 @@ use File::Spec;
 use Template::Filters;
 use Template::Plugin::EnvHash;
 use HTML::SocialMedia;
-use VWF::Utils;
+use Geo::Coder::Free::Utils;
 
 my %blacklist = (
 	'MD' => 1,
@@ -87,7 +87,7 @@ sub new {
 		}
 		if(my $lingua = $args{lingua}) {
 			if($blacklist{uc($lingua->country())}) {
-				die "$ENV{REMOTE_ADDR} is from a blacklisted country " . $lingua->country();
+				die "$ENV{REMOTE_ADDR} is from a blacklisted country ", $lingua->country();
 			}
 		}
 	}
@@ -148,7 +148,7 @@ sub new {
 		}
 	};
 	if($@ || !defined($config)) {
-		die "Configuration error: $@" . $path . '/' . $info->domain_name();
+		die "Configuration error: $@: $path/", $info->domain_name();
 	}
 
 	Template::Filters->use_html_entities();
