@@ -16,15 +16,16 @@ use Text::xSV::Slurp;
 Geo::Coder::Free::Local -
 Provides an interface to locations that you know yourself.
 I have found locations by using GPS apps on a smartphone and by
-inspecting GeoTagged photographs.
+inspecting GeoTagged photographs using
+L<https://github.com/nigelhorne/NJH-Snippets/blob/master/bin/geotag>.
 
 =head1 VERSION
 
-Version 0.28
+Version 0.29
 
 =cut
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use constant	LIBPOSTAL_UNKNOWN => 0;
 use constant	LIBPOSTAL_INSTALLED => 1;
 use constant	LIBPOSTAL_NOT_INSTALLED => -1;
@@ -64,7 +65,7 @@ sub new {
 	# Geo::Coder::Free::Local->new not Geo::Coder::Free::Local::new
 	return unless($class);
 
-	my $rc = {
+	bless {
 		data => xsv_slurp(
 			shape => 'aoh',
 			text_csv => {
@@ -76,9 +77,7 @@ sub new {
 			},
 			string => \join('', grep(!/^\s*(#|$)/, <DATA>))
 		)
-	};
-
-	return bless $rc, $class;
+	}, $class;
 }
 
 =head2 geocode
@@ -116,6 +115,7 @@ sub geocode {
 		my $rc = Geo::Location::Point->new($row);
 		my $str = lc($rc->as_string());
 
+		# ::diag("Compare $str->$lc");
 		if($str eq $lc) {
 			return $rc;
 		}
@@ -126,6 +126,8 @@ sub geocode {
 		}
 	}
 
+	# ::diag(__PACKAGE__, ': ', __LINE__, ': ', $location);
+
 	my $ap;
 	if(($location =~ /USA$/) || ($location =~ /United States$/)) {
 		$ap = $self->{'ap'}->{'us'} // Lingua::EN::AddressParse->new(country => 'US', auto_clean => 1, force_case => 1, force_post_code => 0);
@@ -187,6 +189,7 @@ sub geocode {
 			}
 			$addr{'number'} = $c{'property_identifier'};
 			$addr{'city'} = $c{'suburb'};
+			# ::diag(Data::Dumper->new([\%addr])->Dump());
 			if(my $rc = $self->_search(\%addr, ('number', 'road', 'city', 'state', 'country'))) {
 				return $rc;
 			}
@@ -276,7 +279,7 @@ sub geocode {
 	}
 
 	# Finally try libpostal,
-	# which is good but uses a lot of memory
+	# which is good but uses a lot of memory and can take a very long time to load
 	if($libpostal_is_installed == LIBPOSTAL_UNKNOWN) {
 		if(eval { require Geo::libpostal; } ) {
 			Geo::libpostal->import();
@@ -301,7 +304,7 @@ sub geocode {
 			delete $addr{'state'};
 			$addr{'country'} = 'GB';
 		}
-		# ::diag(__LINE__, ': ', Data::Dumper->new([\%addr])->Dump());
+		# ::diag(__PACKAGE__, ': ', __LINE__, ': ', Data::Dumper->new([\%addr])->Dump());
 		if($addr{'country'} && ($addr{'state'} || $addr{'state_district'})) {
 			if($addr{'country'} =~ /Canada/i) {
 				$addr{'country'} = 'Canada';
@@ -325,6 +328,7 @@ sub geocode {
 				}
 			}
 			if(my $rc = $self->_search(\%addr, ('number', 'road', 'city', 'state', 'country'))) {
+				# ::diag(__PACKAGE__, ': ', __LINE__, ': ', Data::Dumper->new([$rc])->Dump());
 				return $rc;
 			}
 			if($addr{'number'}) {
@@ -355,6 +359,14 @@ sub geocode {
 		} elsif(my $rc = $self->_search(\%addr, ('name', 'road', 'city', 'state', 'country'))) {
 			return $rc;
 		}
+		if($addr{'name'} && !defined($addr{'number'})) {
+			# We know the name of the building but not the street number
+			# ::diag(__LINE__, ': ', $addr{'name'});
+			if(my $rc = $self->_search(\%addr, ('name', 'road', 'city', 'state', 'country'))) {
+				# ::diag(__PACKAGE__, ': ', __LINE__);
+				return $rc;
+			}
+		}
 	}
 
 	$location = uc($location);
@@ -364,7 +376,7 @@ sub geocode {
 			# ::diag($left, '=>', $alternatives{$left});
 			$location =~ s/$left/$alternatives{$left}/;
 			$param{'location'} = $location;
-			# ::diag(__LINE__, ": $location");
+			# ::diag(__LINE__, ": found alternative '$location'");
 			if(my $rc = $self->geocode(\%param)) {
 				# ::diag(__LINE__, ": $location");
 				return $rc;
@@ -388,16 +400,19 @@ sub _search {
 
 	# FIXME: linear search is slow
 	# ::diag(__LINE__, ': ', Data::Dumper->new([\@columns, $data])->Dump());
-	# print Data::Dumper->new([\@columns, $data])->Dump();
+	print Data::Dumper->new([\@columns, $data])->Dump();
+	my @call_details = caller(0);
+	# ::diag(__LINE__, ': called from ', $call_details[2]);
 	foreach my $row(@{$self->{'data'}}) {
 		my $match = 1;
+		my $number_of_columns_matched;
 
 		# ::diag(Data::Dumper->new([$self->{data}])->Dump());
 		# print Data::Dumper->new([$self->{data}])->Dump();
 
 		foreach my $column(@columns) {
-			# ::diag("$column: ", $row->{$column}, '/', $data->{$column});
 			if($data->{$column}) {
+				# ::diag("$column: ", $row->{$column}, '/', $data->{$column});
 				# print "$column: ", $row->{$column}, '/', $data->{$column}, "\n";
 				if(!defined($row->{$column})) {
 					$match = 0;
@@ -407,17 +422,29 @@ sub _search {
 					$match = 0;
 					last;
 				}
+				$number_of_columns_matched++;
 			}
 		}
 		# ::diag("match: $match");
-		if($match) {
+		if($match && ($number_of_columns_matched >= 3)) {
+			my $confidence;
+			if($number_of_columns_matched == scalar(@columns)) {
+				$confidence = 1.0;
+			} elsif($number_of_columns_matched >= 4) {
+				$confidence = 0.7;
+			} else {
+				$confidence = 0.5;
+			}
+			# ::diag("$number_of_columns_matched -> $confidence");
 			return Geo::Location::Point->new(
 				'lat' => $row->{'latitude'},
 				'long' => $row->{'longitude'},
-				'location' => $data->{'location'}
+				'location' => $data->{'location'},
+				'confidence' => $confidence,
 			);
 		}
 	}
+	return;
 }
 
 =head2	reverse_geocode
